@@ -284,12 +284,18 @@ class interface(abstract_instrument_interface.abstract_interface):
         if current_action['action'] == 'move':
             self.logger.info(f"Will move by {current_action['stepsize']}. Begin moving...")
             self.instrument.move_by(current_action['stepsize'])
-            self.wait_until_property_is_false(self.instrument,pyThorlabsAPT.is_in_motion,[self.end_movement,lambda: self._run_sequence(index+1)])
+            #Start checking periodically the value of self.instrument.is_in_motion. It it's true, we read current
+            #position and update it in the GUI. When it becomes False, call self.end_movement
+            self.check_property_until(self.instrument,pyThorlabsAPT.is_in_motion,[True,False],[
+                                                                                                [self.read_position],
+                                                                                                [self.end_movement,lambda: self._run_sequence(index+1)]
+                                                                                                ])
         if current_action['action'] == 'wait':
             self.logger.info(f"Waiting for {float(current_action['time'])} s...")
             QtCore.QTimer.singleShot(int(current_action['time']*1e3), lambda :  self._run_sequence(index+1))
         if current_action['action'] == 'send_trigger':
-            self.update() #the method update is defined in the super class abstract_interface, it will send a trigger to an external function if any trigger is defined
+            self.logger.info(f"Sending trigger (if any is defined)...")
+            self.update() #the method update is defined in the super class abstract_interface, it will send a trigger to an external function if any trigger was defined
             self._run_sequence(index+1)
 
     #### END Functions to talk with low-level driver
